@@ -9,7 +9,7 @@
 project = "python-terminusgps"
 copyright = "2025, Terminus GPS, LLC"
 author = "Terminus GPS, LLC"
-release = "20.4.0"
+release = "20.5.0"
 
 # -- General configuration ---------------------------------------------------
 # https://www.sphinx-doc.org/en/master/usage/configuration.html#general-configuration
@@ -21,6 +21,14 @@ extensions = [
     "sphinx.ext.viewcode",
 ]
 
+intersphinx_mapping = {
+    "python": ("https://docs.python.org/3", None),
+    "django": (
+        "http://docs.djangoproject.com/en/stable/",
+        "http://docs.djangoproject.com/en/stable/_objects/",
+    ),
+}
+
 templates_path = ["_templates"]
 exclude_patterns = []
 
